@@ -33,7 +33,9 @@ def create_conf(output,
                 background_color = "transparent",
                 cogs = True,
                 cogs_p = {"A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z", "None"},
-                cogs_n = {"A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z", "None"}):
+                cogs_n = {"A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z", "None"},
+                tracks_explain = False,
+                contigs_quantity = 1):
     file = open("circos.conf", "w")
     file.write('''karyotype = {folder}/{output}_bands.kar
 chromosomes_units = 100
@@ -49,6 +51,7 @@ chromosomes_display_default = yes
 
 # IMAGE
 <image>
+angle_offset* = {angle_offset}
 <<include conf/image.conf>>
 </image>
 
@@ -56,6 +59,7 @@ chromosomes_display_default = yes
 <ideogram>
 <spacing>
 default = 0.001r
+{explain_space}
 </spacing>
 radius           = 0.8r
 thickness        = 40p
@@ -82,8 +86,8 @@ color      = {font_color}
 fill_under = yes
 thickness  = 1
 file = {folder}/{output}_GC_content.wig
-r0   = 0.62r
-r1   = 0.7r
+r0   = 0.59r
+r1   = 0.65r
 min  = {GC_min}
 max  = {GC_max}
 <rules>
@@ -103,7 +107,7 @@ fill_under = no
 thickness  = 0.5
 file = {folder}/{output}_GC_skew.wig
 r0   = 0.3r
-r1   = 0.6r
+r1   = 0.55r
 min  = {skew_min}
 max  = {skew_max}
 <rules>
@@ -129,7 +133,11 @@ background_stroke_thickness = 1
             content_fill = GC_content_color,
             skew_fill = GC_skew_color,
             skew_line = GC_skew_line_color,
-            font_color = font_color))
+            font_color = font_color,
+            explain_space = '''<pairwise chr{contigs_quantity}>
+                                spacing = 50r
+                                </pairwise>'''.format(contigs_quantity = str(contigs_quantity) + (" chr1" if contigs_quantity > 1 else "")) if tracks_explain else "",
+            angle_offset = "-81" if tracks_explain else "-90"))
     file.close()
     if not os.path.exists("conf"):
         os.mkdir("conf")
@@ -145,12 +153,14 @@ r0               = 1r
 
 <highlight>
 
-#Positive band BGCs
+#Positive band CDSs
 init_counter = highlight:1
 file = {folder}/{output}_CDS_pos.txt
 fill_color = {CDS_positive}
-r1 = 0.85r
-r0 = 0.89r
+r1 = 0.86r
+r0 = 0.90r
+stroke_thickness = 2
+stroke_color ={CDS_positive}
 </highlight>
 
 #Negative
@@ -158,32 +168,40 @@ r0 = 0.89r
 
 file = {folder}/{output}_CDS_neg.txt
 fill_color = {CDS_negative}
-r1 = 0.8r
-r0 = 0.84r
+r1 = 0.75r
+r0 = 0.79r
+stroke_thickness = 2
+stroke_color ={CDS_negative}
 </highlight>
 
 #Positive band tRNAs
 <highlight>
 file = {folder}/{output}_tRNA_pos.txt
 fill_color = {tRNA_positive}
-r1 = 0.85r
-r0 = 0.89r
+r1 = 0.83r
+r0 = 0.85r
+stroke_thickness = 2
+stroke_color ={tRNA_positive}
 </highlight>
 
 #Negative
 <highlight>
 file = {folder}/{output}_tRNA_neg.txt
 fill_color = {tRNA_negative}
+stroke_thickness = 2
+stroke_color ={tRNA_negative}
 r1 = 0.8r
-r0 = 0.84r
+r0 = 0.82r
 </highlight>
 
 #Positive band rRNAs
 <highlight>
 file = {folder}/{output}_rRNA_pos.txt
 fill_color = {rRNA_positive}
-r1 = 0.85r
-r0 = 0.89r
+r1 = 0.83r
+r0 = 0.85r
+stroke_thickness = 2
+stroke_color ={rRNA_positive}
 </highlight>
 
 #Negative
@@ -191,7 +209,9 @@ r0 = 0.89r
 file = {folder}/{output}_rRNA_neg.txt
 fill_color = {rRNA_negative}
 r1 = 0.8r
-r0 = 0.84r
+r0 = 0.82r
+stroke_thickness = 2
+stroke_color ={rRNA_negative}
 </highlight>
 
 '''.format(folder = folder,
@@ -242,8 +262,8 @@ r0 = 0.84r
 
 file = {folder}/{output}_CDS_pos_{name}.txt
 fill_color = {color}
-r1 = 0.9r
-r0 = 0.94r
+r1 = 0.91r
+r0 = 0.95r
 </highlight>
 '''.format(folder = folder, output = output, name = COG["name"], color = COG["color"]))
             if COG["name"] in cogs_n:
@@ -253,8 +273,8 @@ r0 = 0.94r
 
 file = {folder}/{output}_CDS_neg_{name}.txt
 fill_color = {color}
-r1 = 0.75r
-r0 = 0.79r
+r1 = 0.7r
+r0 = 0.74r
 </highlight>
 '''.format(folder = folder, output = output, name = COG["name"], color = COG["color"]))
     file.write("</highlights>")
