@@ -184,6 +184,7 @@ def write_lines(locations, output_, chrx, locus, cogs, verbose = False):
 	hist["freq"] = [0]*len(categories)
 	
 	chrms, counts = np.unique(chrx, return_counts=True)
+	
 	for c in range(len(chrms)):
 		hist["chr"+str(chrms[c])] = [0]*len(categories)
 
@@ -205,14 +206,14 @@ def write_lines(locations, output_, chrx, locus, cogs, verbose = False):
 		writer.writerows(lines)
 		if verbose:
 			print(output_,"created succesfully.")
-	
+
+	# why is this distinction a thing?
 	if len(cogs) == 0:
 		return None
 	else:
 		return hist
 
-def write_cog_files(locations, output, chrx, locus, cogs, verbose = False):
-	
+def write_cog_files(locations, output, chrx, locus, cogs, verbose = False, categories = None):
 	if len(cogs) == 0:
 		return
 	cogs_df = pd.DataFrame.from_dict(cogs)
@@ -222,7 +223,10 @@ def write_cog_files(locations, output, chrx, locus, cogs, verbose = False):
 	cogs_df["chr"] = chrx
 	cogs_df["locus"] = locus
 	cogs_df["main"] = cogs_df["category"].apply(lambda x: "None" if x is None else x[0]) #cogs_df["category"].str[0]
-	categories = map(str, cogs_df["main"].unique())
+	if categories == None:
+		categories = map(str, cogs_df["main"].unique())
+	else:
+		categories = [x for x in categories if x in cogs_df["main"].unique()]
 	#hist = pd.DataFrame(columns = ["cat", "freq"])
 	
 	for c in list(categories):
@@ -298,7 +302,8 @@ def postprocess(chroms):
 
 # Creates feature (CDS, tRNAm, or rRNA) files for CIRCOS.
 # It considers that the genome is not complete.
-def create_feature(gbk_filename, tmp, output, sizes, feat, cogs_dict=None, divided=False, verbose = False, complete=False):
+def create_feature(gbk_filename, tmp, output, sizes, feat, cogs_dict=None, divided=False, verbose = False, complete=False,
+				   wanted_cogs = ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z', '+']):
 	
 	#chrx = '1'
 	
@@ -370,8 +375,8 @@ def create_feature(gbk_filename, tmp, output, sizes, feat, cogs_dict=None, divid
 	n_output = tmp + "_" + feat + "_neg.txt"
 	
 	if divided:
-		write_cog_files(new_pos, p_output, chrms_p, locus_p, cogs_p, verbose = verbose)
-		write_cog_files(new_negs, n_output, chrms_n, locus_n, cogs_n, verbose = verbose)
+		write_cog_files(new_pos, p_output, chrms_p, locus_p, cogs_p, verbose = verbose, categories = wanted_cogs)
+		write_cog_files(new_negs, n_output, chrms_n, locus_n, cogs_n, verbose = verbose, categories = wanted_cogs)
 	#else:
 	hist1 = write_lines(new_pos, p_output, chrms_p, locus_p, cogs_p, verbose = verbose)
 	hist2 = write_lines(new_negs, n_output, chrms_n, locus_n, cogs_n, verbose = verbose)
@@ -380,6 +385,8 @@ def create_feature(gbk_filename, tmp, output, sizes, feat, cogs_dict=None, divid
 		hist1 = hist1.set_index("cat").add(hist2.set_index("cat"), fill_value=0).reset_index().replace("None", "Unclassified")
 		hist1 = hist1.rename(columns={'freq': 'Frequency', 'cat': 'COG Category'})
 		hist1 = hist1[["COG Category", "Frequency"] + ["chr"+str(x) for x in sorted(list(set(chrms_p+chrms_n)))]] # Reordering columns
+		if not "chr1" in hist1:
+			hist1["chr1"] = 0
 		#hist1.columns = ["COG Category", "Frequency"] + ["chr"+str(x) for x in sorted(list(set(chrms_p+chrms_n)))]
 	
 		#if hist1 is not None and hist2 is not None:
@@ -517,7 +524,7 @@ def get_categories(gbk_file, output, deepnog_confidence = 0):
 	
 	try: 
 		#print(command1)
-		genbank2faa.genbankToFaa(gbk_file, output_faa)
+		areCDS = genbank2faa.genbankToFaa(gbk_file, output_faa)
 		#process = subprocess.Popen(command1.split(), stdout=subprocess.PIPE)
 		#output_, error = process.communicate()
 		print()
@@ -531,24 +538,28 @@ def get_categories(gbk_file, output, deepnog_confidence = 0):
 	
 	print("output", output)
 	output_pred = output + "_prediction_deepnog.csv"
-	command2 = "deepnog infer " + output_faa + " --out " + output_pred + " -db cog2020 -t 1"
-	if deepnog_confidence > 0:
-		command2 += " -c " + str(deepnog_confidence)
-	
-	try: 
-		print()
-		print("Deepnog prediction started")
-		print()
-		print(command2)
-		process = subprocess.Popen(command2.split(), stdout=subprocess.PIPE)
-		output_, error = process.communicate()
-		print()
-		print("Deepnog prediction finished succesfully. Predictions saved as", output_pred)
-		print()
-	except:
-		print("Error when predicting categories from " + output_faa + " with deepnog.")
-		return
-	
+	if areCDS:
+		command2 = "deepnog infer " + output_faa + " --out " + output_pred + " -db cog2020 -t 1"
+		if deepnog_confidence > 0:
+			command2 += " -c " + str(deepnog_confidence)
+		
+		try: 
+			print()
+			print("Deepnog prediction started")
+			print()
+			print(command2)
+			process = subprocess.Popen(command2.split(), stdout=subprocess.PIPE)
+			output_, error = process.communicate()
+			print()
+			print("Deepnog prediction finished succesfully. Predictions saved as", output_pred)
+			print()
+		except:
+			print("Error when predicting categories from " + output_faa + " with deepnog.")
+			return
+	else:
+		file = open(output_pred, "w")
+		file.write("sequence_id,prediction,confidence")
+		file.close()
 	# Cross files 
 	
 	cogs_df = pd.read_csv(output_pred, sep=',', usecols=['sequence_id', 'prediction'])
@@ -606,7 +617,8 @@ def base_complete(gbk_file, tmp, output, cds, trna, get_cats, divided, k, init,
 			create_feature_complete(gbk_file, output, sizes, k, "CDS", cogs_dict, divided)
 
 # Base pipeline for non-complete genome.	
-def base(gbk_file, tmp, output, cds, trna, get_cats, divided, complete, rrna = False, deepnog_confidence = 0, verbose = False):
+def base(gbk_file, tmp, output, cds, trna, get_cats, divided, complete, rrna = False, deepnog_confidence = 0, verbose = False,
+         wanted_cogs = ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z', '+']):
 	
 	flag = True
 
@@ -618,6 +630,8 @@ def base(gbk_file, tmp, output, cds, trna, get_cats, divided, complete, rrna = F
 		flag = False
 	elif get_cats:
 		cogs_dict = get_categories(gbk_file, tmp, deepnog_confidence)
+		if type(wanted_cogs) == type(1): #If it is a number
+			wanted_cogs = list(map(lambda x: x[1], sorted([(list(map(lambda cat: cat[0], cogs_dict.values())).count(x), x) for x in "ABCDEFGHIJKLMNOPQRSTUVWXYZ"], reverse = True)[:wanted_cogs])) # Transform it to n more repeated COGs
 	else:
 		cogs_dict = None
 		
@@ -633,14 +647,10 @@ def base(gbk_file, tmp, output, cds, trna, get_cats, divided, complete, rrna = F
 		
 		if trna:
 			_ , _, chrms_tp, chrms_tn, _ = create_feature(gbk_file, tmp, output, sizes, "tRNA", verbose = verbose, complete=complete)
-			#print("\nHIST TRNA\n")
-			#print(hist)
 			chrms_t = [np.unique(chrms_tp, return_counts=True), np.unique(chrms_tn, return_counts=True)]
 			chrms.append(chrms_t)
 		if rrna:
 			_ , _, chrms_rp, chrms_rn, _ = create_feature(gbk_file, tmp, output, sizes, "rRNA", verbose = verbose, complete=complete)
-			#print("\nHIST RRNA\n")
-			#print(hist)
 			chrms_r = [np.unique(chrms_rp, return_counts=True), np.unique(chrms_rn, return_counts=True)]
 			chrms.append(chrms_r)
 		if cds:
@@ -650,10 +660,10 @@ def base(gbk_file, tmp, output, cds, trna, get_cats, divided, complete, rrna = F
 			chrms.append(chrms_c)
 			
 		if divided:
-			cogs_p, cogs_n, _, _, hist = create_feature(gbk_file, tmp, output, sizes, "CDS", cogs_dict, divided, verbose = verbose, complete=complete)
+			cogs_p, cogs_n, _, _, hist = create_feature(gbk_file, tmp, output, sizes, "CDS", cogs_dict, divided, verbose = verbose, complete=complete, wanted_cogs = wanted_cogs)
 
 			
-	return ((sizes, cogs_p, cogs_n, lengths, chrms, hist))
+	return ((sizes, cogs_p, cogs_n, lengths, chrms, hist, wanted_cogs))
 
 def createRaw():
 	gbk_file, output, cds, trna, rrna, get_cats, divided, complete = getArgs()[:]
